#!/usr/bin/env node

const { execSync } = require('child_process');
const os = require('os');
const path = require('path');
const fs = require('fs');
const crypto = require('crypto');

function runCmd(cmd, cwd) {
  try {
    const output = execSync(cmd, { stdio: 'inherit', cwd });
    console.log(`Command "${cmd}" completed successfully.`);
  } catch (error) {
    console.error(`Command "${cmd}" exited with an error.`);
    process.exit(1);
  }
}

// Create a temporary directory
const tempDir = path.join(os.tmpdir(), crypto.randomBytes(16).toString('hex'));
fs.mkdirSync(tempDir);

// Get the path to the library's package.json
const libraryPath = path.dirname(require.resolve('@txhjs/start/package.json'));
const libraryPackageJson = path.join(libraryPath, 'package.json');

// Copy the library's package.json to the temporary directory
fs.copyFileSync(libraryPackageJson, path.join(tempDir, 'package.json'));

// Install the dependencies in the temporary directory
runCmd('npm install', tempDir);

const crossEnvCmd = path.join(tempDir, 'node_modules', 'cross-env', 'dist', 'bin', 'cross-env.js');
const gulpCmd = path.join(tempDir, 'node_modules', 'gulp', 'bin', 'gulp.js');

// Run the scripts using the installed dependencies
runCmd(`node ${crossEnvCmd} NODE_ENV=prod node ${gulpCmd}`, process.cwd());
runCmd(`node ${gulpCmd} serve`, process.cwd());

// Clean up the temporary directory
fs.rmdirSync(tempDir, { recursive: true });
